<h1 align="center" style="margin-top:50px; margin-bottom:70px;">
<img src="https://raw.githubusercontent.com/leseixas/fastelectrons/refs/heads/main/logo.png" style="height: 70px"></h1>

[![License: MIT](https://img.shields.io/github/license/leseixas/fastelectrons?color=green&style=for-the-badge)](LICENSE)    [![PyPI](https://img.shields.io/pypi/v/fastelectrons?color=red&style=for-the-badge)](https://pypi.org/project/fastelectrons/)

## Installation

Install fastelectrons easily using pip, Python’s package manager:
```bash
$ pip install fastelectrons
```

## Getting started

```python

# TODO: 

```

## License

This is an open source code under [MIT License](LICENSE).

## Acknowledgements

We thank financial support from FAPESP [(Grant No. 2022/14549-3)](https://bvs.fapesp.br/pt/auxilios/111791/materiais-de-alta-entropia-inteligiveis-desenvolvendo-modelos-dados-e-aplicacoes/), INCT Materials Informatics (Grant No. 406447/2022-5), and CNPq (Grant No. 311324/2020-7).